Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Ignores map[string]any `yaml:"ignores"`
Fields []Field `yaml:"fields"`
// ManageLabel will the label used by todo meister to track if this issue
// is managed by todo meister. Defaults to managed-by::tm
ManageLabel string `yaml:"manageLabel"`
}
func LoadConfig ¶
func LoadConfig() *Config
type Field ¶
type Field struct {
// Text is the text that will be matched bei todo-meister
Text string `yaml:"text"`
// Labels represent the labels concept used by many issue tools.
// In the end the connectors will decide what to do with the labels.
// e.x. Jira -> priority:minor could be transalted to the native priority field of a jira issue
Labels []string `yaml:"labels"`
}
Click to show internal directories.
Click to hide internal directories.